import 'dart:async';

import 'package:example/models/printer.dart';
import 'package:zebrautility/zebrautility.dart';

class PrintService {
  Future<List<Printer>> scan() async {
    final _completer = Completer<List<Printer>>();

    final List<Printer> _printers = [];

    final zebraPrinter = await Zebrautility.getPrinterInstance(
      onPrinterFound: (name, address, isWifi) {
        final _printer = Printer(name, address);

        _printers.add(_printer);
      },
      onPrinterDiscoveryDone: () {
        _completer.complete(_printers);
      },
      onChangePrinterStatus: (status, color) {
        print(status);
      },
      onPermissionDenied: () {
        print('Denied');
      },
      onDiscoveryError: (errorCode, errorText) {
        print(errorCode);
      },
    );

    zebraPrinter.discoveryPrinters();

    return _completer.future;
  }

  void printTest(Printer device) async {
    final zebraPrinter = await Zebrautility.getPrinterInstance();

    zebraPrinter.connectToPrinter(device.address);

    await Future.delayed(Duration(seconds: 2));

    zebraPrinter.print('''
      ^XA^CI28^MNN^LL206.0      ^CFC
      ^FO30,30.0^FDNº encomenda^FS
      ^CFC
      ^FO424,30.0^FDEC EC-2020/47^FS
           ^CFC
      ^FO30,52.0^FDData entrega^FS
      ^CFC
      ^FO460,52.0^FD12-11-2020^FS
           ^CFC
      ^FO30,74.0^FDTotal recolha^FS
      ^CFC
      ^FO484,74.0^FD0,00 AOA^FS
           ^CFC
      ^FO30,96.0^FDCaução^FS
      ^CFC
      ^FO436,96.0^FD1.200,00 AOA^FS
           ^CFC
      ^FO30,118.0^FDTotal imposto^FS
      ^CFC
      ^FO436,118.0^FD3.528,00 AOA^FS
           ^CFC
      ^FO30,140.0^FDTotal sem imposto^FS
      ^CFC
      ^FO424,140.0^FD26.400,00 AOA^FS
           ^CFC
      ^FO30,162.0^FDTotal factura^FS
      ^CFC
      ^FO424,162.0^FD31.128,00 AOA^FS
           ^CFC
      ^FO30,184.0^FDTotal a pagar^FS
      ^CFC
      ^FO424,184.0^FD29.928,00 AOA^FS
    ^XZ
    ''');

    await Future.delayed(Duration(seconds: 3));

    zebraPrinter.disconnect();
  }
}
